**Example 1: 删除负载均衡监听器**



Input: 

```
tccli ecm DeleteListener --cli-unfold-argument  \
    --LoadBalancerId lb-f9zyj3kb \
    --ListenerId lb-knd4jr8m
```

Output: 
```
{
    "Response": {
        "RequestId": "dcb32a03-de71-437a-9f92-a703e6d82123"
    }
}
```

